@@ -72,8 +72,8 @@ def handle_input_data(request):
         try:
             func(request)
         except Exception, e:
-            request.server.logger.error('before_request_func_list raise exception. func: %s, e: %s',
-                                        func.__name__, e)
+            request.server.logger.error('before_request_func_list raise exception. func: %s, e: %s, traceback: %s',
+                                        func.__name__, e, __import__('traceback').format_exc())
     view_func_exc = False
     view_func_result = None
 
@@ -81,9 +81,8 @@ def handle_input_data(request):
         view_func_result = view_func(request)
     except Exception, e:
         view_func_result = e
-        error = 'view_func raise exception. endpoint: %s, view_func: %s, e: %s' % (
-            endpoint, view_func.__name__, e
-        )
+        error = 'view_func raise exception. endpoint: %s, view_func: %s, e: %s, traceback: %s' % (
+            endpoint, view_func.__name__, e, __import__('traceback').format_exc())
         request.server.logger.error(error)
         request.push(error if request.server.debug else constants.ERROR_INTERNAL)
         view_func_exc = True
@@ -93,8 +92,8 @@ def handle_input_data(request):
         try:
             func(request, view_func_result)
         except Exception, e:
-            request.server.logger.error('after_request_func_list raise exception. func: %s, view_func_result: %s, e: %s',
-                                        func.__name__, view_func_result, e)
+            request.server.logger.error('after_request_func_list raise exception. func: %s, view_func_result: %s, e: %s, traceback: %s',
+                                        func.__name__, view_func_result, e, __import__('traceback').format_exc())
 
     # 如果view_func异常，就要关闭socket
     if view_func_exc:
@@ -240,8 +239,8 @@ class TcpRequestHandler(asynchat.async_chat):
             try:
                 func(self)
             except Exception, e:
-                self.server.logger.error('create_request_func_list raise exception. func: %s, e: %s',
-                                         func.__name__, e)
+                self.server.logger.error('create_request_func_list raise exception. func: %s, e: %s, traceback: %s',
+                                         func.__name__, e, __import__('traceback').format_exc())
 
     def collect_incoming_data(self, data):
         # 直接用默认提供的方法就行
@@ -264,8 +263,8 @@ class TcpRequestHandler(asynchat.async_chat):
             try:
                 func(self)
             except Exception, e:
-                self.server.logger.error('teardown_request_func_list raise exception. func: %s, e: %s',
-                                         func.__name__, e)
+                self.server.logger.error('teardown_request_func_list raise exception. func: %s, e: %s, traceback: %s',
+                                         func.__name__, e, __import__('traceback').format_exc())
 
     @property
     def server(self):
@@ -340,8 +339,8 @@ class UdpRequestHandler(object):
             try:
                 func(self)
             except Exception, e:
-                self.server.logger.error('create_request_func_list raise exception. func: %s, e: %s',
-                                         func.__name__, e)
+                self.server.logger.error('create_request_func_list raise exception. func: %s, e: %s, traceback: %s',
+                                         func.__name__, e, __import__('traceback').format_exc())
         handle_input_data(self)
 
         # teardown_request_func_list
@@ -349,8 +348,8 @@ class UdpRequestHandler(object):
             try:
                 func(self)
             except Exception, e:
-                self.server.logger.error('teardown_request_func_list raise exception. func: %s, e: %s',
-                                         func.__name__, e)
+                self.server.logger.error('teardown_request_func_list raise exception. func: %s, e: %s, traceback: %s',
+                                         func.__name__, e, __import__('traceback').format_exc())
 
     def push(self, data):
         """
